@@ -23,6 +23,7 @@
 
 #include <geocode-glib/geocode-place.h>
 #include <geocode-glib/geocode-enum-types.h>
+#include <geocode-glib/geocode-glib-private.h>
 
 /**
  * SECTION:geocode-place
@@ -52,6 +53,7 @@ struct _GeocodePlacePrivate {
         char *country_code;
         char *country;
         char *continent;
+        GIcon *icon;
 };
 
 enum {
@@ -72,6 +74,7 @@ enum {
         PROP_COUNTRY_CODE,
         PROP_COUNTRY,
         PROP_CONTINENT,
+        PROP_ICON,
 };
 
 G_DEFINE_TYPE (GeocodePlace, geocode_place, G_TYPE_OBJECT)
@@ -160,6 +163,11 @@ geocode_place_get_property (GObject    *object,
                                     geocode_place_get_continent (place));
                 break;
 
+        case PROP_ICON:
+                g_value_set_object (value,
+                                    geocode_place_get_icon (place));
+                break;
+
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
                 break;
@@ -240,6 +248,10 @@ geocode_place_set_property(GObject      *object,
                 geocode_place_set_continent (place, g_value_get_string (value));
                 break;
 
+        case PROP_ICON:
+                _geocode_place_set_icon (place, g_value_get_object (value));
+                break;
+
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
                 break;
@@ -252,6 +264,7 @@ geocode_place_dispose (GObject *gplace)
         GeocodePlace *place = (GeocodePlace *) gplace;
 
         g_clear_object (&place->priv->location);
+        g_clear_object (&place->priv->icon);
 
         g_clear_pointer (&place->priv->name, g_free);
         g_clear_pointer (&place->priv->street_address, g_free);
@@ -478,6 +491,19 @@ geocode_place_class_init (GeocodePlaceClass *klass)
                                      G_PARAM_READWRITE |
                                      G_PARAM_STATIC_STRINGS);
         g_object_class_install_property (gplace_class, PROP_CONTINENT, pspec);
+
+        /**
+         * GeocodePlace:icon:
+         *
+         * #GIcon representing the @GeocodePlace.
+         */
+        pspec = g_param_spec_object ("icon",
+                                     "Icon",
+                                     "An icon representing the the place",
+                                     G_TYPE_ICON,
+                                     G_PARAM_READWRITE |
+                                     G_PARAM_STATIC_STRINGS);
+        g_object_class_install_property (gplace_class, PROP_ICON, pspec);
 }
 
 static void
@@ -532,6 +558,7 @@ geocode_place_new_with_location (const char      *name,
 /**
  * geocode_place_set_name:
  * @place: A place
+ * @name: the name of place
  *
  * Sets the name of the @place to @name.
  **/
@@ -551,6 +578,8 @@ geocode_place_set_name (GeocodePlace *place,
  * @place: A place
  *
  * Gets the name of the @place.
+ *
+ * Returns: The name of the @place.
  **/
 const char *
 geocode_place_get_name (GeocodePlace *place)
@@ -565,6 +594,8 @@ geocode_place_get_name (GeocodePlace *place)
  * @place: A place
  *
  * Gets the type of the @place.
+ *
+ * Returns: The type of the @place.
  **/
 GeocodePlaceType
 geocode_place_get_place_type (GeocodePlace *place)
@@ -597,6 +628,8 @@ geocode_place_set_location (GeocodePlace *place,
  * geocode_place_get_location:
  * @place: A place
  *
+ * Gets the associated location object.
+ *
  * Returns: (transfer none): The associated location object.
  **/
 GeocodeLocation *
@@ -630,6 +663,8 @@ geocode_place_set_street_address (GeocodePlace *place,
  * @place: A place
  *
  * Gets the street address of the @place.
+ *
+ * Returns: The street address of the @place.
  **/
 const char *
 geocode_place_get_street_address (GeocodePlace *place)
@@ -662,6 +697,8 @@ geocode_place_set_street (GeocodePlace *place,
  * @place: A place
  *
  * Gets the street of the @place.
+ *
+ * Returns: The street of the @place.
  **/
 const char *
 geocode_place_get_street (GeocodePlace *place)
@@ -694,6 +731,8 @@ geocode_place_set_building (GeocodePlace *place,
  * @place: A place
  *
  * Gets the building of the @place.
+ *
+ * Returns: The building of the @place.
  **/
 const char *
 geocode_place_get_building (GeocodePlace *place)
@@ -726,6 +765,8 @@ geocode_place_set_postal_code (GeocodePlace *place,
  * @place: A place
  *
  * Gets the postal code of the @place.
+ *
+ * Returns: The postal code of the @place.
  **/
 const char *
 geocode_place_get_postal_code (GeocodePlace *place)
@@ -758,6 +799,8 @@ geocode_place_set_area (GeocodePlace *place,
  * @place: A place
  *
  * Gets the area of the @place.
+ *
+ * Returns: The area of the @place.
  **/
 const char *
 geocode_place_get_area (GeocodePlace *place)
@@ -790,6 +833,8 @@ geocode_place_set_town (GeocodePlace *place,
  * @place: A place
  *
  * Gets the town of the @place.
+ *
+ * Returns: The town of the @place.
  **/
 const char *
 geocode_place_get_town (GeocodePlace *place)
@@ -822,6 +867,8 @@ geocode_place_set_county (GeocodePlace *place,
  * @place: A place
  *
  * Gets the county of the @place.
+ *
+ * Returns: The country of the @place.
  **/
 const char *
 geocode_place_get_county (GeocodePlace *place)
@@ -854,6 +901,8 @@ geocode_place_set_state (GeocodePlace *place,
  * @place: A place
  *
  * Gets the state of the @place.
+ *
+ * Returns: The state of the @place.
  **/
 const char *
 geocode_place_get_state (GeocodePlace *place)
@@ -886,6 +935,8 @@ geocode_place_set_administrative_area (GeocodePlace *place,
  * @place: A place
  *
  * Gets the local administrative area of the @place.
+ *
+ * Returns: The local administrative area of the @place.
  **/
 const char *
 geocode_place_get_administrative_area (GeocodePlace *place)
@@ -918,6 +969,8 @@ geocode_place_set_country_code (GeocodePlace *place,
  * @place: A place
  *
  * Gets the ISO country code of the @place.
+ *
+ * Returns: The ISO country code of the @place.
  **/
 const char *
 geocode_place_get_country_code (GeocodePlace *place)
@@ -950,6 +1003,8 @@ geocode_place_set_country (GeocodePlace *place,
  * @place: A place
  *
  * Gets the country of the @place.
+ *
+ * Returns: The country of the @place.
  **/
 const char *
 geocode_place_get_country (GeocodePlace *place)
@@ -982,6 +1037,8 @@ geocode_place_set_continent (GeocodePlace *place,
  * @place: A place
  *
  * Gets the continent of the @place.
+ *
+ * Returns: The continent of the @place.
  **/
 const char *
 geocode_place_get_continent (GeocodePlace *place)
@@ -990,3 +1047,30 @@ geocode_place_get_continent (GeocodePlace *place)
 
         return place->priv->continent;
 }
+
+/**
+ * geocode_place_get_icon:
+ * @place: A place
+ *
+ * Gets the #GIcon representing the @place.
+ *
+ * Returns: (transfer none): The #GIcon representing the @place.
+ **/
+GIcon *
+geocode_place_get_icon (GeocodePlace *place)
+{
+        g_return_val_if_fail (GEOCODE_IS_PLACE (place), NULL);
+
+        return place->priv->icon;
+}
+
+void
+_geocode_place_set_icon (GeocodePlace *place,
+                         GIcon        *icon)
+{
+        g_return_if_fail (GEOCODE_IS_PLACE (place));
+        g_return_if_fail (icon != NULL);
+
+        g_clear_object (&place->priv->icon);
+        place->priv->icon = g_object_ref (icon);
+}
